% drawBeam(spos, epos, bdir, bHG)
%   beam drawing... ?

function drawBeam(spos, epos, bdir, bHG)

  % space between beams
  dsmax = 20;
  lambda = 1064e-6;
  cbeam = [1 0.5 0.5];
  cwaist = [0 0 0];
  zwaist = 5;
  
  % draw central line
  drawLine(spos, epos, 'r');

  % beam parameters
  z0x = bHG(1);
  zx = bHG(2);
  z0y = bHG(3);
  zy = bHG(4);
  
  % init counter for steps around waist
  dsmin = min([dsmax, z0x, z0y]);
  
  % draw beam segment
  dd = vecLen(spos - epos);
  [R, rx] = beamRW(z0x, zx, lambda);
  [R, ry] = beamRW(z0y, zy, lambda);
  drawCircle(spos, bdir, rx, ry, cbeam, 8);
  dnow = 0;
  isLast = 0;
  while ~isLast
    rxp = rx;
    ryp = ry;
    
    % check for short step around X-waist
    dnx = zx + dnow;
    dsx = -dnx - z0x;
    if dsx < -2 * z0x
      dsx = dsmax;
    elseif dsx < z0x
      dsx = z0x;
    end
      
    dny = zy + dnow;
    dsy = -dny - z0y;
    if dsy < -2 * z0y
      dsy = dsmax;
    elseif dsy < z0y
      dsy = z0y;
    end

    ds = min([dsx, dsy, dsmax]);
    if ds < 0.1
      [dsx, dsy, dsmax, zx, zy, z0x, z0y]
      warning('bad step')
      ds = 0.1;
    end
      
    if dd - dnow < ds
      ds = dd - dnow;
      isLast = 1;
    end
    dnow = dnow + ds;
    [R, rx] = beamRW(z0x, zx + dnow , lambda);
    [R, ry] = beamRW(z0y, zy + dnow, lambda);
    drawBeamSeg(spos + bdir * dnow, bdir, rx, ry, ds, rxp, ryp, cbeam);
  end

  % draw circle at each X waist
  vx = vecNorm(cross([0; 0; 1], bdir));
  if zx < 0 & zx + dd > 0
    [R, rx] = beamRW(z0x, 0, lambda);
    [R, ry] = beamRW(z0y, zy - zx, lambda);
    cpos = spos - bdir * zx;
    drawCircle(cpos, bdir, zwaist * rx, zwaist * ry, cwaist, 16);

    vxr = zwaist * rx * vx;
    drawLine(cpos - vxr, cpos + vxr, cwaist);
  end
    
  % draw circle at each Y waist
  if zy < 0 & zy + dd > 0
    [R, rx] = beamRW(z0x, zx - zy, lambda);
    [R, ry] = beamRW(z0y, 0, lambda);
    cpos = spos - bdir * zy;
    drawCircle(cpos, bdir, zwaist * rx, zwaist * ry, cwaist, 16);

    vyr = zwaist * ry * cross(vx, bdir);
    drawLine(cpos - vyr, cpos + vyr, cwaist);
  end
end

% drawBeamSeg
function drawBeamSeg(pos, vaxis, rx, ry, dp, rxp, ryp, c)

  % make radial vector and rotation matrix
  N = 8;
  dth = 2 * pi / N;
  vr = vecNorm(cross([0; 0; 1], vaxis));
  mr = vecRot(vaxis, dth);
  
  % create start and end positions
  spos = zeros(3, 2 * N + 1);
  epos = zeros(3, 2 * N + 1);
  spos(:, 1) = vr * rx + pos;
  epos(:, N + 1) = spos(:, 1);
  
  % segment line
  spos(:, N + 2) = spos(:, 1);
  epos(:, N + 2) = vr * rxp + pos - vaxis * dp;

  % loop around the beam segment
  th = 0;
  for n = 1:N
    vr = mr * vr;
    th = th + dth;
    
    % ellipse line
    phi = atan2(rx * sin(th), ry * cos(th));
    rad = sqrt((cos(phi) * rx)^2 + (sin(phi) * ry)^2);
    spos(:, n + 1) = vr * rad + pos;
    epos(:, n) = spos(:, n + 1);
    
    % segment line
    phi = atan2(rxp * sin(th), ryp * cos(th));
    rad = sqrt((cos(phi) * rxp)^2 + (sin(phi) * ryp)^2);
    spos(:, n + 1 + N) = spos(:, n + 1);
    epos(:, n + 1 + N) = vr * rad + pos - vaxis * dp;
  end

  % draw the circle
  drawLine(spos, epos, c);
  
end
