% p = getGasBoxParams(version)
%

function p = getGasBoxParams(ver)
  
  
  %%%%%%%%%%%%%%%%%%%%%%
  % gas parameters
  p.Ntrial = 500;
  p.tEnd = 10;
  p.dtBin = 1e-4;
  p.vMax = 4e3;
  p.dvBin = 1;
  
  p.temp = 293;  % temperature, K
  p.mass = 2;    % particle mass, AMU
  
  switch ver
    
    case 1
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = 'ERM at 5mm';
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % shapes
      boundingBox = Box(1, 1, 1);
      boundingBox.setColor([0.2 0.5 0.2]);
      
      testMass = Cylinder(0.2, 0.17);
      testMass.setBottomPosition([0 0 0]);
      testMass.setColor([0.5 0.2 1]);
      
      reactionMass = Cylinder(0.13, 0.17);
      reactionMass.setTopPosition([0 0 -0.005]);
      reactionMass.setColor([1 1 0]');
      
      p.shapes = {boundingBox testMass reactionMass};

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % drawing 
      p.cameraPos = boundingBox.length .* [0.95; 0.9; 0.8] / 2;
      p.cameraDir = -1 * p.cameraPos;
      p.cameraFOV = 60;
      p.lightPos = [0.45 0 0.48]';
      
    case 2
      % exploded view of case 1
      p = getGasBoxParams(1);
      
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = [p.name ': Exploded'];
      
      p.shapes{2}.setBottomPosition([-0.05 -0.05 0.05]);
      p.shapes{3}.setTopPosition([0.05 0.05 -0.05]);
      
    case 3
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = 'Annulus 22cm ID at 5mm, ERM at 25mm';
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % shapes
      boundingBox = Box(1, 1, 1);
      boundingBox.setColor([0.2 0.5 0.2]);
      
      testMass = Cylinder(0.2, 0.17);
      testMass.setBottomPosition([0 0 0]);
      testMass.setColor([0.5 0.2 1]);
      
      reactionMass = Cylinder(0.1, 0.17);
      reactionMass.setTopPosition([0 0 -0.025]);
      reactionMass.setColor([1 1 0]');
      
      reactionMass2 = Annulus(0.0201, 0.17, 0.11);
      reactionMass2.setTopPosition([0 0 -0.005]);
      reactionMass2.setColor([1 0 0]');
      
      p.shapes = {boundingBox testMass reactionMass reactionMass2};

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % drawing 
      p.cameraPos = boundingBox.length .* [0.95; 0.9; 0.8] / 2;
      p.cameraDir = -1 * p.cameraPos;
      p.cameraFOV = 60;
      p.lightPos = [0.45 0 0.48]';
      
    case 4
      % exploded view of case 3
      p = getGasBoxParams(3);
      
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = [p.name ': Exploded'];
      
      p.shapes{2}.setBottomPosition([-0.05 -0.05 0.05]);
      p.shapes{3}.setTopPosition([0.05 0.05 -0.05]);
      
    case 5
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = '10cm thick CP at 2cm';
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % shapes
      boundingBox = Box(1, 1, 1);
      boundingBox.setColor([0.2 0.5 0.2]);
      
      testMass = Cylinder(0.2, 0.17);
      testMass.setBottomPosition([0 0 0]);
      testMass.setColor([0.5 0.2 1]);
      
      reactionMass = Cylinder(0.1, 0.17);
      reactionMass.setTopPosition([0 0 -0.02]);
      reactionMass.setColor([1 1 0]');
      
      p.shapes = {boundingBox testMass reactionMass};

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % drawing 
      p.cameraPos = boundingBox.length .* [0.95; 0.9; 0.8] / 2;
      p.cameraDir = -1 * p.cameraPos;
      p.cameraFOV = 60;
      p.lightPos = [0.45 0 0.48]';
      
    case 6
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = 'Annulus 22cm ID at 5mm, ERM at 35mm';
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % shapes
      boundingBox = Box(1, 1, 1);
      boundingBox.setColor([0.2 0.5 0.2]);
      
      testMass = Cylinder(0.2, 0.17);
      testMass.setBottomPosition([0 0 0]);
      testMass.setColor([0.5 0.2 1]);
      
      reactionMass = Cylinder(0.1, 0.17);
      reactionMass.setTopPosition([0 0 -0.035]);
      reactionMass.setColor([1 1 0]');
      
      reactionMass2 = Annulus(0.0301, 0.17, 0.11);
      reactionMass2.setTopPosition([0 0 -0.005]);
      reactionMass2.setColor([1 0 0]');
      
      p.shapes = {boundingBox testMass reactionMass reactionMass2};

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % drawing 
      p.cameraPos = boundingBox.length .* [0.95; 0.9; 0.8] / 2;
      p.cameraDir = -1 * p.cameraPos;
      p.cameraFOV = 60;
      p.lightPos = [0.45 0 0.48]';
      
    case 7
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p = getGasBoxParams(3);
      p.ver = ver;
      p.name = [p.name ': Vented (1cm thick Annulus)'];
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % shapes - modify annulus thickness
      p.shapes{4}.setLengthAndRadii(0.01, 0.17, 0.11);      
      p.shapes{4}.setTopPosition([0 0 -0.005]);
  
    case 8
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = 'Annulus 22cm ID at 5mm, no ERM';
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % shapes
      boundingBox = Box(1, 1, 1);
      boundingBox.setColor([0.2 0.5 0.2]);
      
      testMass = Cylinder(0.2, 0.17);
      testMass.setBottomPosition([0 0 0]);
      testMass.setColor([0.5 0.2 1]);
      
      reactionMass2 = Annulus(0.13, 0.17, 0.11);
      reactionMass2.setTopPosition([0 0 -0.005]);
      reactionMass2.setColor([1 0 0]');
      
      p.shapes = {boundingBox testMass reactionMass2};

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % drawing 
      p.cameraPos = boundingBox.length .* [0.95; 0.9; 0.8] / 2;
      p.cameraDir = -1 * p.cameraPos;
      p.cameraFOV = 60;
      p.lightPos = [0.45 0 0.48]';
      

    case 9
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = 'Annulus 22cm ID at 5mm, Engraved ESD';
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % shapes
      boundingBox = Box(1, 1, 1);
      boundingBox.setColor([0.2 0.5 0.2]);
      
      testMass = Cylinder(0.2, 0.17);
      testMass.setBottomPosition([0 0 0]);
      testMass.setColor([0.5 0.2 1]);
      
      % inner finger
      reactionMass1 = Annulus(0.13, 0.118, 0.113);
      reactionMass1.setTopPosition([0 0 -0.005]);
      reactionMass1.setColor([1 0 0]');
      
      % gap
      reactionMass2 = Annulus(0.11, 0.123, 0.118);
      reactionMass2.setTopPosition([0 0 -0.025]);
      reactionMass2.setColor([1 0.5 0]');

      % second finger
      reactionMass3 = Annulus(0.13, 0.128, 0.123);
      reactionMass3.setTopPosition([0 0 -0.005]);
      reactionMass3.setColor([1 0 0]');

      % gap
      reactionMass4 = Annulus(0.11, 0.133, 0.128);
      reactionMass4.setTopPosition([0 0 -0.025]);
      reactionMass4.setColor([1 0.5 0]');
      
      % third finger
      reactionMass5 = Annulus(0.13, 0.138, 0.133);
      reactionMass5.setTopPosition([0 0 -0.005]);
      reactionMass5.setColor([1 0 0]');
      
      % gap
      reactionMass6 = Annulus(0.11, 0.143, 0.138);
      reactionMass6.setTopPosition([0 0 -0.025]);
      reactionMass6.setColor([1 0.5 0]');

      % forth finger
      reactionMass7 = Annulus(0.13, 0.148, 0.143);
      reactionMass7.setTopPosition([0 0 -0.005]);
      reactionMass7.setColor([1 0 0]');

      % gap
      reactionMass8 = Annulus(0.11, 0.153, 0.148);
      reactionMass8.setTopPosition([0 0 -0.025]);
      reactionMass8.setColor([1 0.5 0]');
      
      % fifth finger
      reactionMass9 = Annulus(0.13, 0.158, 0.153);
      reactionMass9.setTopPosition([0 0 -0.005]);
      reactionMass9.setColor([1 0 0]');
      
      % gap
      reactionMass10 = Annulus(0.11, 0.163, 0.158);
      reactionMass10.setTopPosition([0 0 -0.025]);
      reactionMass10.setColor([1 0.5 0]');

      % sixth finger
      reactionMass11 = Annulus(0.13, 0.168, 0.163);
      reactionMass11.setTopPosition([0 0 -0.005]);
      reactionMass11.setColor([1 0 0]');

      p.shapes = {boundingBox testMass reactionMass1  reactionMass2 ...
         reactionMass3 reactionMass4 reactionMass5 reactionMass6 ...
         reactionMass7 reactionMass8 reactionMass9 reactionMass10 ...
         reactionMass11};

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % drawing 
      p.cameraPos = boundingBox.length .* [0.95; 0.9; 0.8] / 2;
      p.cameraDir = -1 * p.cameraPos;
      p.cameraFOV = 60;
      p.lightPos = [0.45 0 0.48]';
      

    case 10
      % exploded view of case 9
      p = getGasBoxParams(9);
      
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = [p.name ': Exploded'];
      
      p.shapes{2}.setBottomPosition([-0.05 -0.05 0.05]);
      for n = 3:2:numel(p.shapes)
        p.shapes{n}.setTopPosition([0.05 0.05 -0.05]);
      end
      for n = 4:2:numel(p.shapes)
        p.shapes{n}.setTopPosition([0.05 0.05 -0.075]);
      end
      
    case 11
      % zoom of case 10
      p = getGasBoxParams(10);
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % drawing 
      p.cameraPos = p.shapes{1}.length .* [0.95; 0.9; 0.8] / 2;
      p.cameraDir = -0.1 * [4.5 3.5 4]';
      p.cameraFOV = 25;
      p.lightPos = [0.45 0 0.48]';
      
      
    case 12
      % modification of case 1
      p = getGasBoxParams(1);
      
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p.ver = ver;
      p.name = ['TM Alone'];
      
      p.shapes = p.shapes(1:2);
      p.shapes{2}.setPosition([0 0 0]);
      
      case {101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112}
      %%%%%%%%%%%%%%%%%%%%%%
      % identity
      p = getGasBoxParams(ver - 100);
      p.ver = ver;
      p.name = [p.name ': big box'];
      
      p.shapes{1}.setSize([2 2 2]');
      
  end
  
end
